@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
 """Utility functions that may be implemented in external packages."""
 import re
 
-
-charset_pattern = re.compile(r'charset=(?P<charset>.+)$', re.I | re.U)
+charset_pattern = re.compile(r"charset=(?P<charset>.+)$", re.I | re.U)
 
 
 def content_type_to_charset(content_type):
@@ -16,7 +14,7 @@ def content_type_to_charset(content_type):
     """
     match = re.search(charset_pattern, content_type)
     if match:
-        return match.group('charset')
+        return match.group("charset")
 
 
 def url_basename(url, content_type):
@@ -30,7 +28,7 @@ def url_basename(url, content_type):
     somefile.rst
 
     """
-    return url.split('/')[-1]
+    return url.split("/")[-1]
 
 
 def import_member(import_string):
@@ -42,6 +40,6 @@ def import_member(import_string):
     True
 
     """
-    module_name, factory_name = str(import_string).rsplit('.', 1)
+    module_name, factory_name = str(import_string).rsplit(".", 1)
     module = __import__(module_name, globals(), locals(), [factory_name], 0)
     return getattr(module, factory_name)
